@@ -16,7 +16,7 @@ import seaborn as sns
 import sqlalchemy as sa
 import sys
 import time
-import umap.umap_ as umap
+# import umap.umap_ as umap
 from fuzzywuzzy import fuzz
 from geopandas import GeoDataFrame
 from geopandas import points_from_xy
@@ -40,7 +40,7 @@ from sklearn.neighbors import KNeighborsClassifier
 from sklearn.svm import SVC
 from sklearn.tree import DecisionTreeClassifier
 from sklearn.ensemble import BaggingClassifier, RandomForestClassifier, StackingClassifier
-from sklearn.metrics import classification_report, confusion_matrix, plot_confusion_matrix
+from sklearn.metrics import classification_report, confusion_matrix, ConfusionMatrixDisplay
 from sklearn.decomposition import PCA
 from sklearn.cluster import KMeans, SpectralClustering, AgglomerativeClustering, DBSCAN, Birch
 from sklearn.manifold import TSNE
@@ -596,18 +596,18 @@ class data_visualization:
     def __init__(self):
         pass
 
-    def plot_confusion(self, model, X, y, class_names, normalized='true'):
-        titles_options = [("Confusion matrix, without normalization", None),
-                          ("Normalized confusion matrix", normalized)]
-        for title, normalize in titles_options:
-            display = plot_confusion_matrix(model, X, y,
-                                         display_labels=class_names,
-                                         cmap=plt.cm.Blues,
-                                         normalize=normalize)
-            display.ax_.set_title(title)
-            print(title)
-            print(display.confusion_matrix)
-        plt.show()
+#     def plot_confusion(self, model, X, y, class_names, normalized='true'):
+#         titles_options = [("Confusion matrix, without normalization", None),
+#                           ("Normalized confusion matrix", normalized)]
+#         for title, normalize in titles_options:
+#             display = plot_confusion_matrix(model, X, y,
+#                                          display_labels=class_names,
+#                                          cmap=plt.cm.Blues,
+#                                          normalize=normalize)
+#             display.ax_.set_title(title)
+#             print(title)
+#             print(display.confusion_matrix)
+#         plt.show()
 
     def data_visualization(self, df, column_list, removal_list, title, x_axis):
         try:
@@ -684,26 +684,26 @@ class data_visualization:
         print(model_name)
         plt.show()
 
-    def umap_graph(self, df):
-        numerical_df = df.select_dtypes(exclude='object')
-        for c in numerical_df.columns:
-            pt = PowerTransformer()
-            numerical_df.loc[:, c] = pt.fit_transform(np.array(numerical_df[c]).reshape(-1, 1))
-        categorical_df = df.select_dtypes(include='object')
-        categorical_df = pd.get_dummies(categorical_df)
-        categorical_weight = len(df.select_dtypes(include='object').columns) / len(df.columns)
-        fit1 = umap.UMAP(metric='l2').fit(numerical_df)
-        fit2 = umap.UMAP(metric='dice').fit(categorical_df)
-        intersection = umap.general_simplicial_set_intersection(fit1.graph_, fit2.graph_, weight=categorical_weight)
-        intersection = umap.reset_local_connectivity(intersection)
-        embedding = umap.simplicial_set_embedding(fit1._raw_data, intersection, fit1.n_components, 
-                                                        fit1._initial_alpha, fit1._a, fit1._b, 
-                                                        fit1.repulsion_strength, fit1.negative_sample_rate, 
-                                                        200, 'random', np.random, fit1.metric, 
-                                                        fit1._metric_kwds, False)
-        plt.figure(figsize=(20, 10))
-        plt.scatter(*embedding.T, s=2, cmap='Spectral', alpha=1.0)
-        plt.show()
+#     def umap_graph(self, df):
+#         numerical_df = df.select_dtypes(exclude='object')
+#         for c in numerical_df.columns:
+#             pt = PowerTransformer()
+#             numerical_df.loc[:, c] = pt.fit_transform(np.array(numerical_df[c]).reshape(-1, 1))
+#         categorical_df = df.select_dtypes(include='object')
+#         categorical_df = pd.get_dummies(categorical_df)
+#         categorical_weight = len(df.select_dtypes(include='object').columns) / len(df.columns)
+#         fit1 = umap.UMAP(metric='l2').fit(numerical_df)
+#         fit2 = umap.UMAP(metric='dice').fit(categorical_df)
+#         intersection = umap.general_simplicial_set_intersection(fit1.graph_, fit2.graph_, weight=categorical_weight)
+#         intersection = umap.reset_local_connectivity(intersection)
+#         embedding = umap.simplicial_set_embedding(fit1._raw_data, intersection, fit1.n_components, 
+#                                                         fit1._initial_alpha, fit1._a, fit1._b, 
+#                                                         fit1.repulsion_strength, fit1.negative_sample_rate, 
+#                                                         200, 'random', np.random, fit1.metric, 
+#                                                         fit1._metric_kwds, False)
+#         plt.figure(figsize=(20, 10))
+#         plt.scatter(*embedding.T, s=2, cmap='Spectral', alpha=1.0)
+#         plt.show()
 
 
 ########################### Model Training ###########################
